Package 'ggsegAicha'

Title: AICHA Atlas for the 'ggseg' Ecosystem
Description: AICHA (Atlas of Intrinsic Connectivity of Homotopic Areas) atlas for the 'ggseg' ecosystem. Provides a unified 'ggseg_atlas' object with both 2D polygon geometry and 3D vertex indices, for use with 'ggseg' and 'ggseg3d'.
Authors: Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>)
Maintainer: Athanasia Mo Mowinckel <[email protected]>
License: MIT + file LICENSE
Version: 2.0.1
Built: 2026-05-26 06:16:04 UTC
Source: https://github.com/ggsegverse/ggsegAicha

Help Index


AICHA Atlas (Atlas of Intrinsic Connectivity of Homotopic Areas)

Description

Brain atlas for the AICHA cortical parcellation with 342 regions. The original volumetric atlas in MNI space was projected to fsaverage using the CBIG lab's registration fusion. Contains both 2D polygon geometry for ggseg::geom_brain() and 3D vertex indices for ggseg3d::ggseg3d().

Usage

aicha()

Value

A ggseg.formats::ggseg_atlas object (cortical).

References

Joliot M, Jobard G, Naveau M, Delcroix N, Petit L, Zago L, ... & Tzourio-Mazoyer N (2015). AICHA: An atlas of intrinsic connectivity of homotopic areas. Journal of Neuroscience Methods, 254, 46-59. doi:10.1016/j.jneumeth.2015.07.013

Examples

aicha()
## Not run: plot(aicha())